pub struct QueueId { /* private fields */ }Expand description
Queue identifier with support for absolute and relative paths The path field always contains the absolute path (with instance_id embedded for relative paths)
Implementations
Sourceimpl QueueId
impl QueueId
Sourcepub fn to_key_derivation_base(&self) -> &str
pub fn to_key_derivation_base(&self) -> &str
Get the queue path as a base for cryptographic key derivation
Sourcepub fn to_cloud_queue_path(&self, base_prefix: &str) -> String
pub fn to_cloud_queue_path(&self, base_prefix: &str) -> String
Get the queue path for cloud storage with base prefix Example: “prefix/instance_id/queue_name/”
Sourcepub fn to_store_dir(&self, base: &Path) -> PathBuf
pub fn to_store_dir(&self, base: &Path) -> PathBuf
Construct the full filesystem path to the store directory Example: /base/instance_id/queue_name/store
Sourcepub fn to_store_path(&self, base: &Path, file_id: &UintN) -> PathBuf
pub fn to_store_path(&self, base: &Path, file_id: &UintN) -> PathBuf
Construct the full filesystem path to a store file Example: /base/instance_id/queue_name/store/abc/def/123.store
Sourcepub fn to_wal_dir(&self, base: &Path) -> PathBuf
pub fn to_wal_dir(&self, base: &Path) -> PathBuf
Construct the full filesystem path to the WAL directory Example: /base/instance_id/queue_name/wal
Sourcepub fn to_wal_path(&self, base: &Path, file_id: &UintN) -> PathBuf
pub fn to_wal_path(&self, base: &Path, file_id: &UintN) -> PathBuf
Construct the full filesystem path to a WAL file Example: /base/instance_id/queue_name/wal/123.wal
Sourcepub fn to_cloud_key(&self, base_prefix: &str, file_id: &UintN) -> String
pub fn to_cloud_key(&self, base_prefix: &str, file_id: &UintN) -> String
Construct the cloud storage key for a store file (always uses forward slashes) Example: prefix/instance_id/queue_name/abc/def/123.store Note: Only store files are stored in cloud storage, not WAL files